
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.24'
version = '1.2.24'
full_version = '1.2.24'
git_revision = '4433a9675cd8b6c77de91358c266c8b24363b5f2'
release = True

if not release:
    version = full_version
    short_version += ".dev"
